Padding

Struct Padding 

pub struct Padding {
    pub top: f32,
    pub right: f32,
    pub bottom: f32,
    pub left: f32,
}
An amount of space to pad for each side of a box

You can leverage the From trait to build Padding conveniently:

let padding = Padding::from(20);              // 20px on all sides
let padding = Padding::from([10, 20]);        // top/bottom, left/right

Normally, the padding method of a widget will ask for an Into<Padding>, so you can easily write:

impl Widget {
    pub fn padding(mut self, padding: impl Into<Padding>) -> Self {
        // ...
        self
    }
}

let widget = Widget::new().padding(20);              // 20px on all sides
let widget = Widget::new().padding([10, 20]);        // top/bottom, left/right

Fields

top: f32

Top padding

right: f32

Right padding

bottom: f32

Bottom padding

left: f32

Left padding

Implementations

Source

impl Padding

pub const ZERO: Padding

Padding of zero

pub const fn new(padding: f32) -> Padding

Create a Padding that is equal on all sides.

pub fn top(self, top: impl Into<Pixels>) -> Self

Sets the top of the Padding.

pub fn bottom(self, bottom: impl Into<Pixels>) -> Self

Sets the bottom of the Padding.

pub fn left(self, left: impl Into<Pixels>) -> Self

Sets the left of the Padding.

pub fn right(self, right: impl Into<Pixels>) -> Self

Sets the right of the Padding.

pub fn vertical(self) -> f32

Returns the total amount of vertical Padding.

pub fn horizontal(self) -> f32

Returns the total amount of horizontal Padding.

pub fn fit(self, inner: Size, outer: Size) -> Self

Fits the Padding between the provided inner and outer Size.